@@ -386,7 +386,7 @@ sh=as.numeric(pp["shape"])
 pmin=as.numeric(pp["min"]);pmax=as.numeric(pp["max"]);
 ll=seq(min(dd),max(dd),  (max(dd)-min(dd))/100 )
 ds=dbeta((ll-pmin)/(pmax-pmin),shape1=mm*sh,shape2=(1-mm)*sh)/(pmax-pmin)
-if(!add) hist(dd,freq=F,xlim=c(pmin,pmax),xlab="",main="Beta Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(pmin,pmax),xlab="",main="Beta Histogram",ylim=ylim,breaks=breaks,...)
 lines(ll,ds,...)
 }
 ###########################################################  
@@ -402,7 +402,7 @@ res=log(shapei)+log(sh)+(sh-1)*log(q)+(shapei-1)*log(k)-log(pmax-pmin);
 return(exp(res))
 }
 ds=dkuma(ll,MM,sh,pmin,pmax)
-if(!add) hist(dd,freq=F,xlim=c(pmin,pmax),xlab="",main="Kumaraswamy Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(pmin,pmax),xlab="",main="Kumaraswamy Histogram",ylim=ylim,breaks=breaks,...)
 lines(ll,ds,...)
 }
 #}
@@ -411,7 +411,7 @@ lines(ll,ds,...)
 #######################################  OK
 if(model%in%c("Gaussian"))
 {
-if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Gaussian Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Gaussian Histogram",ylim=ylim,breaks=breaks,...)
 lines(seq(min(dd),max(dd),0.1),dnorm(seq(min(dd),max(dd),0.1),mean=MM,sd=sqrt(VV)),...)
 }
 
@@ -420,7 +420,7 @@ if(model%in%c("StudentT","Gaussian_misp_StudentT"))
 {
 df=as.numeric(round(1/pp["df"]))
 ll=seq(min(dd),max(dd),  (max(dd)-min(dd))/100 )
-if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Student T Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Student T Histogram",ylim=ylim,breaks=breaks,...)
 lines(ll,dt((ll-MM)/sqrt(VV),df=df),...)/sqrt(VV)
 }
 
@@ -431,7 +431,7 @@ if(model%in%c("SkewStudentT","Gaussian_misp_SkewStudentT"))
   nu=as.numeric(round(1/pp["df"]))
 ll=seq(min(dd),max(dd),  (max(dd)-min(dd))/100 )
   d_st=sn::dst((ll-MM)/sqrt(VV), xi=0, omega=1, alpha=alpha, nu=nu)/sqrt(VV)
-  if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Skew-T Histogram",ylim=ylim,breaks=breaks)
+  if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Skew-T Histogram",ylim=ylim,breaks=breaks,...)
   lines(ll,d_st,...)
 }
 
@@ -444,7 +444,7 @@ if(model %in% c("SkewGaussian"))
    alpha=skew/sill^0.5
 ll=seq(min(dd),max(dd),  (max(dd)-min(dd))/100 )
    d_sn=sn::dsn((ll-MM)/sqrt(VV), xi=0, omega=omega,alpha=alpha)/sqrt(VV)
-   if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Skew Gaussian Histogram",ylim=ylim,breaks=breaks)
+   if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Skew Gaussian Histogram",ylim=ylim,breaks=breaks,...)
    lines(ll,d_sn,...)
 }
 
@@ -455,7 +455,7 @@ if(model %in% c("Weibull"))
    shape=pp["shape"]
   ll=seq(min(dd),max(dd),  (max(dd)-min(dd))/100 )
    d_w=dweibull(ll,shape=shape,scale=exp(MM)/(gamma(1+1/shape )))
-   if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Weibull Histogram",ylim=ylim,breaks=breaks)
+   if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Weibull Histogram",ylim=ylim,breaks=breaks,...)
    lines(ll,d_w,...)
 }
 
@@ -466,7 +466,7 @@ if(model %in% c("Gamma"))
    shape=pp["shape"]
   ll=seq(min(dd),max(dd),  (max(dd)-min(dd))/100 )
    d_g=dgamma(ll,shape=shape/2,rate=shape/(2*exp(MM)))
-   if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Gamma Histogram",ylim=ylim,breaks=breaks)
+   if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Gamma Histogram",ylim=ylim,breaks=breaks,...)
    lines(ll,d_g,...) 
 
 }
@@ -480,7 +480,7 @@ ll=seq(min(dd),max(dd),  (max(dd)-min(dd))/100 )
    return(exp(a))
    }
    d_l = dlnorm(ll,MM,VV)
-   if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="LogGaussian Histogram",ylim=ylim,breaks=breaks)
+   if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="LogGaussian Histogram",ylim=ylim,breaks=breaks,...)
    lines(ll,d_l,...) 
 }
 #######################################  OK
@@ -488,7 +488,7 @@ if(model %in% c("Logistic"))
 {
 ll=seq(min(dd),max(dd),  (max(dd)-min(dd))/100 )
 d_l = dlogis(ll,location = MM, scale = sqrt(VV))
-if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Logistic Histogram",ylim=ylim)
+if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Logistic Histogram",ylim=ylim,breaks=breaks,...)
 lines(ll,d_l,...) 
 }
 #######################################  OK
@@ -498,7 +498,7 @@ shape=pp["shape"]
 cc=gamma(1+1/shape)*gamma(1-1/shape)
 ll=seq(min(dd),max(dd),  (max(dd)-min(dd))/100 )
 d_l = actuar::dllogis(ll,shape = shape,scale=exp(MM)/cc)
-if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="LogLogistic Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="LogLogistic Histogram",ylim=ylim,breaks=breaks,...)
 lines(ll,d_l,...) 
 
 }
@@ -516,7 +516,7 @@ d=exp(-0.5*s^2)
 return(tail*c*d*a)
 }
 ds=qtpsas1((ll-MM)/sqrt(VV),skew,tail)/sqrt(VV)
-if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="SAS Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="SAS Histogram",ylim=ylim,breaks=breaks,...)
    lines(ll,ds,...) 
 }
 
@@ -538,7 +538,7 @@ c=dnorm(inverse_lamb(x,tail),0,1)
 return(b*c/(a*sqrt(VV)))
 }
 ds=qth((ll-MM)/sqrt(VV),tail,VV)
-if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Tukey-h Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Tukey-h Histogram",ylim=ylim,breaks=breaks,...)
 lines(ll,ds,...) 
 }
 ####################################### OK
@@ -568,7 +568,7 @@ qtpTukeyh22= function(x,tail1,tail2,VV){
   return(c(ds2,ds1))
 }
 ds=qtpTukeyh22((ll-MM)/sqrt(VV),tail1,tail2,VV)
-if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Tukey-hh Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Tukey-hh Histogram",ylim=ylim,breaks=breaks,...)
 lines(ll,ds,...) 
 }
 #######################################   OK
@@ -587,7 +587,7 @@ qtpGaussian1=function(x,eta,VV){
   return(c(ds2,ds1))
 }
 ds=qtpGaussian1((ll-MM)/sqrt(VV),skew,VV)
-if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Two-Piece Gaussian Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Two-Piece Gaussian Histogram",ylim=ylim,breaks=breaks,...)
 lines(ll,ds,...) 
 }
 ####################################### OK
@@ -607,7 +607,7 @@ qtpt = function(x,skew,df,VV){
   return(c(ds2,ds1))
 }
 ds=qtpt((ll-MM)/sqrt(VV),skew,df,VV)
-if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Two-Piece Student Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Two-Piece Student Histogram",ylim=ylim,breaks=breaks,...)
 lines(ll,ds,...)
 }
 ####################################### OK
@@ -640,7 +640,7 @@ dTTukeyh= function(x,tail,skew,VV){
   return(c(ds2,ds1))
 }
 ds=dTTukeyh((ll-MM)/sqrt(VV),tail,skew,VV)
-if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Two-Piece Tukey-h Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Two-Piece Tukey-h Histogram",ylim=ylim,breaks=breaks,...)
 lines(ll,ds,...)
 }
 #######################################  OK
@@ -663,7 +663,7 @@ ptpbimodal1 = function(x,skew,delta,df,VV){
   return(c(ds2,ds1))
 }
 ds=ptpbimodal1((ll-MM)/sqrt(VV),skew,delta,df,VV)
-if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Two-Piece Bimodal Histogram",ylim=ylim,breaks=breaks)
+if(!add) hist(dd,freq=F,xlim=c(min(dd),max(dd)),xlab="",main="Two-Piece Bimodal Histogram",ylim=ylim,breaks=breaks,...)
 lines(ll,ds,...)
 }
 
@@ -672,7 +672,7 @@ if(model %in% c("BinomialNeg")) {
 ll=as.numeric(table(dd)/length(dd))
 y=sort(unique(as.numeric(dd)))#min(dd):max(dd)
 ds=dnbinom(y, size=fit$n, prob=pnorm(MM))
-if(!add) plot(y,ll,type = "h", col = "blue",main="Binomial Negative Histogram", xlab="",  ylab="",lwd = 2)
+if(!add) plot(y,ll,type = "h", col = "blue",main="Binomial Negative Histogram", xlab="",  ylab="",lwd = 2,...)
 points(y,ds,type = "p", col = "black", lwd = 3)
 lines(y,ds)
 }
@@ -681,7 +681,7 @@ if(model %in% c("Binomial")) {
 ll=as.numeric(table(dd)/length(dd))
 y=sort(unique(as.numeric(dd)))
 ds=dbinom(y, size=fit$n, prob=pnorm(MM))
-if(!add) plot(y,ll,type = "h", col = "blue",main="Binomial Histogram", xlab="",  ylab="",lwd = 2)
+if(!add) plot(y,ll,type = "h", col = "blue",main="Binomial Histogram", xlab="",  ylab="",lwd = 2,...)
 points(y,ds,type = "p", col = "black", lwd = 3)
 lines(y,ds)
 }
@@ -690,7 +690,7 @@ if(model %in% c("BinomialLogistic")) {
 ll=as.numeric(table(dd)/length(dd))
 y=sort(unique(as.numeric(dd)))
 ds=dbinom(y, size=fit$n, prob=plogis(MM))
-if(!add) plot(y,ll,type = "h", col = "blue",main="Binomial-Logistic Histogram", xlab="",  ylab="",lwd = 2)
+if(!add) plot(y,ll,type = "h", col = "blue",main="Binomial-Logistic Histogram", xlab="",  ylab="",lwd = 2,...)
 points(y,ds,type = "p", col = "black", lwd = 3)
 lines(y,ds)
 }
@@ -699,7 +699,7 @@ if(model %in% c("Poisson")) {
 ll=as.numeric(table(dd)/length(dd))
 y=sort(unique(as.numeric(dd)))
 ds=dpois(y, lambda=exp(MM))
-if(!add) plot(y,ll,type = "h", col = "blue",main="Poisson Histogram", xlab="",  ylab="",lwd = 2)
+if(!add) plot(y,ll,type = "h", col = "blue",main="Poisson Histogram", xlab="",  ylab="",lwd = 2,...)
 points(y,ds,type = "p", col = "black", lwd = 3)
 lines(y,ds)
 }
