@@ -8,8 +8,7 @@ GeoVarestbootstrap=function(fit,K=100,sparse=FALSE,GPU=NULL,  local=c(1,1),optim
   lower=NULL, upper=NULL,method="cholesky", alpha=0.95, memdist=TRUE, M=30,L=500,seed=1)
 {
 
-
-if(fit$coordt==0)  fit$coordt=NULL
+if(length(fit$coordt)==1) fit$coordt=NULL
 
 if(is.null(fit$sensmat)) stop("Sensitivity matrix is missing: use sensitivity=TRUE in GeoFit")
 if(is.null(fit$sensmat)) stop("Sensitivity matrix is missing: use sensitivity=TRUE in GeoFit")
@@ -45,7 +44,7 @@ set.seed(seed)
 while(k<=K){
 Sys.sleep(0.1)
 if(method=="cholesky") {
-
+#print(coords)#print(fit$coordt)
   if(is.null(fit$copula))
 data_sim = GeoSim(coordx=coords,coordt=fit$coordt,
      coordx_dyn=fit$coordx_dyn, anisopars=fit$anisopars,
